pub trait Encodingwhere
Self: Send,{
// Required methods
fn get_type(&self) -> EncodingType;
fn encode(&self) -> &Vec<u8> ⓘ;
fn transform(
&self,
input: &PixelFormat,
output: &PixelFormat,
) -> Box<dyn Encoding>;
}Required Methods
fn get_type(&self) -> EncodingType
Sourcefn encode(&self) -> &Vec<u8> ⓘ
fn encode(&self) -> &Vec<u8> ⓘ
Transform this encoding from its representation into a byte vector that can be passed to the client.
Sourcefn transform(
&self,
input: &PixelFormat,
output: &PixelFormat,
) -> Box<dyn Encoding>
fn transform( &self, input: &PixelFormat, output: &PixelFormat, ) -> Box<dyn Encoding>
Translates this encoding type from an input pixel format to an output format.